import json
import os
from typing import Optional, Union

import click
import requests
from dotenv import load_dotenv

from zenodo.depositions.deposition import Deposition
from zenodo.entities.metadata import Metadata

load_dotenv()


@click.command()
@click.option("--metadata", help="Optional json of metadata for the deposition.")
@click.option(
    "--metadata_file",
    type=click.Path(exists=True, file_okay=True, dir_okay=False),
    help="Optional json file of metadata for the deposition.",
)
@click.option(
    "--prereserve-doi",
    is_flag=True,
    help="Prereserve a DOI (not pushed to Datacite until deposition is published).",
)
@click.option("--silent", default=False, help="Don't print any output")
@click.option(
    "--token",
    prompt=True,
    prompt_required=False,
    hide_input=True,
    show_default="ENVVAR: 'ZENODO_TOKEN'",
    help="Required when the envvar is not set.",
)
def create(
    metadata: Union[str, Metadata, None] = Metadata(),
    metadata_file: Optional[str] = None,
    prereserve_doi: Optional[bool] = None,
    silent: bool = True,
    token: Optional[str] = None,
):
    if token is None:
        token = os.getenv("ZENODO_TOKEN")

    metadata_parsed: Metadata
    if metadata is None:
        metadata_parsed = Metadata()
    elif isinstance(metadata, str):
        metadata_parsed = Metadata.parse_raw(metadata)
    elif isinstance(metadata, Metadata):
        metadata_parsed = metadata

    if metadata_file is not None:
        metadata_parsed = Metadata.parse_file(metadata_file)

    if prereserve_doi is True:
        metadata_parsed.prereserve_doi = True

    base_url = os.getenv("ZENODO_URL")
    header = {"Authorization": f"Bearer {token}"}
    response = requests.post(
        f"{base_url}/api/deposit/depositions",
        json={"metadata": metadata_parsed.dict(exclude_none=True)},
        headers=header,
    )
    if not silent:
        json_response = json.dumps(response.json(), indent=4)
        click.echo(json_response)

    response.raise_for_status()
    return Deposition.parse_obj(response.json())


if __name__ == "__main__":
    create()



from dataclasses import dataclass
from typing import Optional

from zenodo.entities.zenodo_file import ZenodoFile


@dataclass
class Record:
    created: str
    doi: str
    files: list[ZenodoFile]
    links: dict
    id: int
    metadata: dict
    owners: list[int]
    revision: int
    stats: dict
    updated: str
    conceptdoi: Optional[str] = None
    conceptrecid: Optional[str] = None



from enum import Enum
from typing import Optional

from pydantic import BaseModel


class Creator(BaseModel):
    name: str = "Placeholder"
    affiliation: Optional[str] = None
    orcid: Optional[str] = None
    gnd: Optional[str] = None


class ContributorType(Enum):
    contact_person = "ContactPerson"
    data_collector = "DataCollector"
    data_curator = "DataCurator"
    data_manager = "DataManager"
    distributor = "Distributor"
    editor = "Editor"
    funder = "Funder"
    hosting_institution = "HostingInstitution"
    producer = "Producer"
    project_leader = "ProjectLeader"
    project_manager = "ProjectManager"
    registration_agency = "RegistrationAgency"
    registration_authority = "RegistrationAuthority"
    related_person = "RelatedPerson"
    researcher = "Researcher"
    research_group = "ResearchGroup"
    rights_holder = "RightsHolder"
    supervisor = "Supervisor"
    sponsor = "Sponsor"
    work_package_leader = "WorkPackageLeader"
    other = "Other"


class Contributor(Creator):
    type: ContributorType



from typing import Optional

from pydantic import BaseModel

from zenodo.entities.metadata import Metadata
from zenodo.entities.zenodo_file import ZenodoFile


class Deposition(BaseModel):
    created: str
    doi: str
    doi_url: str
    files: list[ZenodoFile]
    id: int
    metadata: Metadata
    modified: str
    owner: int
    record_id: int
    record_url: Optional[str] = None
    state: str
    submitted: bool
    title: str



import io
import os
import re

from setuptools import find_packages, setup


def read(filename):
    filename = os.path.join(os.path.dirname(__file__), filename)
    text_type = type("")
    with io.open(filename, mode="r", encoding="utf-8") as fd:
        return re.sub(text_type(r":[a-z]+:`~?(.*?)`"), text_type(r"``\1``"), fd.read())


setup(
    name="zenodo-rest",
    version="0.0.0a0",
    url="https://github.com/kykrueger/zenodo_py.git",
    license="MIT",
    author="Kyle Krueger",
    author_email="kyle.s.krueger@gmail.com",
    description=(
        "A python wrapper of Zenodo's REST API",
        "for python and the command line.",
    ),
    long_description=read("README.md"),
    packages=find_packages(exclude=("tests",)),
    install_requires=["click", "pydantic", "python-dotenv", "requests"],
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
)



import json
import os
from typing import Optional

import click
import requests
from dotenv import load_dotenv

from zenodo.records.record import Record

load_dotenv()


@click.command()
@click.option(
    "--query", "-q", help="Search query (using Elasticsearch query string syntax)."
)
@click.option(
    "--status", help="Filter result based on deposit status (either draft or published)"
)
@click.option(
    "--sort",
    help=(
        "Sort order (bestmatch or mostrecent)."
        "Prefix with minus to change form ascending to descending (e.g. -mostrecent)."
    ),
)
@click.option("--page", help="Page number for pagination")
@click.option("--size", help="Number of results to return per page.")
@click.option(
    "--all-versions",
    help="Show (true or 1) or hide (false or 0) all versions of deposits.",
)
@click.option("--silent", default=False, help="Don't print any output")
@click.option(
    "--token",
    prompt=True,
    prompt_required=False,
    hide_input=True,
    show_default="ENVVAR: 'ZENODO_TOKEN'",
    help="Required when the envvar is not set.",
)
def get(
    query: Optional[str] = None,
    status: Optional[str] = None,
    sort: Optional[str] = None,
    page: Optional[str] = None,
    size: Optional[int] = None,
    all_versions: Optional[str] = None,
    silent: bool = True,
    token: Optional[str] = None,
) -> list[Record]:
    if token is None:
        token = os.getenv("ZENODO_TOKEN")

    base_url = os.getenv("ZENODO_URL")
    header = {"Authorization": f"Bearer {token}"}
    response = requests.get(f"{base_url}/api/records", headers=header)
    if not silent:
        json_response = json.dumps(response.json(), indent=4)
        click.echo(json_response)

    response.raise_for_status()
    return [Record(**x) for x in response.json()["hits"]["hits"]]


if __name__ == "__main__":
    get()
